==> v1.2.zip: mk0.software.bildduplikate/Mk0.Software.Bildduplikate/Form1.cs <==
﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Mk0.Software.Bildduplikate
{
    public partial class Form1 : Form
    {
        static readonly string[] suffixes = { "Bytes", "KB", "MB", "GB", "TB", "PB" };
        private int line = 0, total = 0, offset = 0;
        private string file;

        private List<Duplicate> duplicates = new List<Duplicate>();

        public Form1()
        {
            InitializeComponent();
        }

        private void ButtonCSV_Click(object sender, EventArgs e)
        {
            openFileDialog1.Title = "Select CSV";
            openFileDialog1.DefaultExt = "csv";
            openFileDialog1.Filter = "CSV (*.csv)|*.csv";
            openFileDialog1.FilterIndex = 2;
            openFileDialog1.CheckFileExists = true;
            openFileDialog1.CheckPathExists = true;

            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                LoadCSV(openFileDialog1.FileName);
            }
        }

        private void LoadCSV(string fileName)
        {
            line = 0;
            total = 0;
            file = fileName;
            offset = 0;
            duplicates.Clear();

            using (StreamReader reader = new StreamReader(fileName))
            {
                while (!reader.EndOfStream)
                {
                    var line = reader.ReadLine();
                    var values = line.Split(',');

                    Duplicate d = new Duplicate(values[0], values[1]);
                    duplicates.Add(d);
                }
            }

            total = duplicates.Count;

            LoadDuplicates(line);
        }

        private void LoadDuplicates(int lineDup)
        {
            if (duplicates.Count > lineDup)
            {
                if (File.Exists(duplicates.ElementAt(lineDup).Path1) && File.Exists(duplicates.ElementAt(lineDup).Path2))
                {
                    Image img1 = GetCopyImage(duplicates.ElementAt(lineDup).Path1);
                    Image img2 = GetCopyImage(duplicates.ElementAt(lineDup).Path2);
                    pictureBox1.Image = img1;
                    pictureBox2.Image = img2;
                    FileInfo f1 = new FileInfo(duplicates.ElementAt(lineDup).Path1);
                    FileInfo f2 = new FileInfo(duplicates.ElementAt(lineDup).Path2);
                    label1.Text = Path.GetFileName(duplicates.ElementAt(lineDup).Path1) + Environment.NewLine + FormatSize(f1.Length) + Environment.NewLine + f1.LastWriteTime;
                    label2.Text = Path.GetFileName(duplicates.ElementAt(lineDup).Path2) + Environment.NewLine + FormatSize(f2.Length) + Environment.NewLine + f2.LastWriteTime;
                    label3.Text = total + " Duplikate";
                    UIElementsVisible(true);
                }
                else
                {
                    File_DeleteLine(lineDup);
                    total--;
                    line++;
                    LoadDuplicates(line);
                }
            }
            else
            {
                MessageBox.Show("Alle Duplikate in CSV abgearbeitet", "Fertig!", MessageBoxButtons.OK, MessageBoxIcon.Information);
                UIElementsVisible(false);
            }
        }

        private void UIElementsVisible(bool vis)
        {
            label1.Visible = vis;
            label2.Visible = vis;
            label3.Visible = vis;
            buttonDel1.Visible = vis;
            buttonDel2.Visible = vis;
            buttonKeinDuplikat.Visible = vis;
            pictureBox1.Visible = vis;
            pictureBox2.Visible = vis;
        }

        private string FormatSize(long length)
        {
            int counter = 0;
            decimal number = (decimal)length;
            while (Math.Round(number / 1024) >= 1)
            {
                number /= 1024;
                counter++;
            }
            return string.Format("{0:n1}{1}", number, suffixes[counter]);
        }

        private void ButtonKeinDuplikat_Click(object sender, EventArgs e)
        {
            File_DeleteLine(line);
            line++;
            total--;
            LoadDuplicates(line);
        }

        private void ButtonDel1_Click(object sender, EventArgs e)
        {
            File.Delete(duplicates.ElementAt(line).Path1);
            File_DeleteLine(line);
            line++;
            total--;
            LoadDuplicates(line);
        }

        private void ButtonDel2_Click(object sender, EventArgs e)
        {
            File.Delete(duplicates.ElementAt(line).Path2);
            File_DeleteLine(line);
            line++;
            total--;
            LoadDuplicates(line);
        }

        private Image GetCopyImage(string path)
        {
            using (Image image = Image.FromFile(path))
            {
                Bitmap bitmap = new Bitmap(image);
                return bitmap;
            }
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.C)
            {
                ButtonCSV_Click(sender, e);
            }
            else if (e.KeyCode == Keys.D1 || e.KeyCode == Keys.NumPad1)
            {
                ButtonDel1_Click(sender, e);
            }
            else if (e.KeyCode == Keys.D2 || e.KeyCode == Keys.NumPad2)
            {
                ButtonDel2_Click(sender, e);
            }
            else if (e.KeyCode == Keys.D0 || e.KeyCode == Keys.NumPad0)
            {
                ButtonKeinDuplikat_Click(sender, e);
            }
            else if (e.KeyCode == Keys.R)
            {
                ButtonReload_Click(sender, e);
            }
        }

        private void ButtonReload_Click(object sender, EventArgs e)
        {
            LoadDuplicates(line);
        }

        private void File_DeleteLine(int lineFile)
        {
            int linetodelete = lineFile + 1 - offset;
            offset++;
            StringBuilder sb = new StringBuilder();
            using (StreamReader sr = new StreamReader(file))
            {
                int Countup = 0;
                while (!sr.EndOfStream)
                {
                    Countup++;
                    if (Countup != linetodelete)
                    {
                        using (StringWriter sw = new StringWriter(sb))
                        {
                            sw.WriteLine(sr.ReadLine());
                        }
                    }
                    else
                    {
                        sr.ReadLine();
                    }
                }
            }
            using (StreamWriter sw = new StreamWriter(file))
            {
                sw.Write(sb.ToString());
            }
            Debug.Print("lösche Zeile " + linetodelete);
        }
    }
}

==> v1.3.zip: mk0.software.bildduplikate/Mk0.Software.Bildduplikate/Form1.cs <==
﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace Mk0.Software.Bildduplikate
{
    public partial class Form1 : Form
    {
        static readonly string[] suffixes = { "Bytes", "KB", "MB", "GB", "TB", "PB" };
        private int line = 0, total = 0, offset = 0;
        private string file;

        private List<Duplicate> duplicates = new List<Duplicate>();

        public Form1()
        {
            InitializeComponent();
        }

        private void ButtonCSV_Click(object sender, EventArgs e)
        {
            openFileDialog1.Title = "Select CSV";
            openFileDialog1.DefaultExt = "csv";
            openFileDialog1.Filter = "CSV (*.csv)|*.csv";
            openFileDialog1.FilterIndex = 2;
            openFileDialog1.CheckFileExists = true;
            openFileDialog1.CheckPathExists = true;

            if (openFileDialog1.ShowDialog() == DialogResult.OK)
            {
                LoadCSV(openFileDialog1.FileName);
            }
        }

        private void LoadCSV(string fileName)
        {
            line = 0;
            total = 0;
            file = fileName;
            offset = 0;
            duplicates.Clear();

            using (StreamReader reader = new StreamReader(fileName))
            {
                while (!reader.EndOfStream)
                {
                    var line = reader.ReadLine();
                    var values = line.Split(',');

                    Duplicate d = new Duplicate(values[0], values[1]);
                    duplicates.Add(d);
                }
            }

            total = duplicates.Count;

            LoadDuplicates(line);
        }

        private void LoadDuplicates(int lineDup)
        {
            if (duplicates.Count > lineDup)
            {
                if (File.Exists(duplicates.ElementAt(lineDup).Path1) && File.Exists(duplicates.ElementAt(lineDup).Path2))
                {
                    Image img1 = GetCopyImage(duplicates.ElementAt(lineDup).Path1);
                    Image img2 = GetCopyImage(duplicates.ElementAt(lineDup).Path2);
                    pictureBox1.Image = img1;
                    pictureBox2.Image = img2;
                    FileInfo f1 = new FileInfo(duplicates.ElementAt(lineDup).Path1);
                    FileInfo f2 = new FileInfo(duplicates.ElementAt(lineDup).Path2);
                    label1.Text = Path.GetFileName(duplicates.ElementAt(lineDup).Path1) + Environment.NewLine + FormatSize(f1.Length) + Environment.NewLine + f1.LastWriteTime + Environment.NewLine + img1.Width + "x" + img1.Height;
                    label2.Text = Path.GetFileName(duplicates.ElementAt(lineDup).Path2) + Environment.NewLine + FormatSize(f2.Length) + Environment.NewLine + f2.LastWriteTime + Environment.NewLine + img2.Width + "x" + img2.Height;
                    label3.Text = total + " Duplikate";
                    UIElementsVisible(true);
                }
                else
                {
                    File_DeleteLine(lineDup);
                    total--;
                    line++;
                    LoadDuplicates(line);
                }
            }
            else
            {
                MessageBox.Show("Alle Duplikate in CSV abgearbeitet", "Fertig!", MessageBoxButtons.OK, MessageBoxIcon.Information);
                UIElementsVisible(false);
            }
        }

        private void UIElementsVisible(bool vis)
        {
            label1.Visible = vis;
            label2.Visible = vis;
            label3.Visible = vis;
            buttonDel1.Visible = vis;
            buttonDel2.Visible = vis;
            buttonKeinDuplikat.Visible = vis;
            pictureBox1.Visible = vis;
            pictureBox2.Visible = vis;
        }

        private string FormatSize(long length)
        {
            int counter = 0;
            decimal number = (decimal)length;
            while (Math.Round(number / 1024) >= 1)
            {
                number /= 1024;
                counter++;
            }
            return string.Format("{0:n1}{1}", number, suffixes[counter]);
        }

        private void ButtonKeinDuplikat_Click(object sender, EventArgs e)
        {
            File_DeleteLine(line);
            line++;
            total--;
            LoadDuplicates(line);
        }

        private void ButtonDel1_Click(object sender, EventArgs e)
        {
            File.Delete(duplicates.ElementAt(line).Path1);
            File_DeleteLine(line);
            line++;
            total--;
            LoadDuplicates(line);
        }

        private void ButtonDel2_Click(object sender, EventArgs e)
        {
            File.Delete(duplicates.ElementAt(line).Path2);
            File_DeleteLine(line);
            line++;
            total--;
            LoadDuplicates(line);
        }

        private Image GetCopyImage(string path)
        {
            using (Image image = Image.FromFile(path))
            {
                Bitmap bitmap = new Bitmap(image);
                return bitmap;
            }
        }

        private void Form1_KeyDown(object sender, KeyEventArgs e)
        {
            if (e.KeyCode == Keys.C)
            {
                ButtonCSV_Click(sender, e);
            }
            else if (e.KeyCode == Keys.D1 || e.KeyCode == Keys.NumPad1)
            {
                ButtonDel1_Click(sender, e);
            }
            else if (e.KeyCode == Keys.D2 || e.KeyCode == Keys.NumPad2)
            {
                ButtonDel2_Click(sender, e);
            }
            else if (e.KeyCode == Keys.D0 || e.KeyCode == Keys.NumPad0)
            {
                ButtonKeinDuplikat_Click(sender, e);
            }
            else if (e.KeyCode == Keys.R)
            {
                ButtonReload_Click(sender, e);
            }
        }

        private void ButtonReload_Click(object sender, EventArgs e)
        {
            LoadDuplicates(line);
        }

        private void File_DeleteLine(int lineFile)
        {
            int linetodelete = lineFile + 1 - offset;
            offset++;
            StringBuilder sb = new StringBuilder();
            using (StreamReader sr = new StreamReader(file))
            {
                int Countup = 0;
                while (!sr.EndOfStream)
                {
                    Countup++;
                    if (Countup != linetodelete)
                    {
                        using (StringWriter sw = new StringWriter(sb))
                        {
                            sw.WriteLine(sr.ReadLine());
                        }
                    }
                    else
                    {
                        sr.ReadLine();
                    }
                }
            }
            using (StreamWriter sw = new StreamWriter(file))
            {
                sw.Write(sb.ToString());
            }
            Debug.Print("lösche Zeile " + linetodelete);
        }
    }
}
